==> rucksack-4.4.0.tgz: package/lib/index.js <==
"use strict";

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var browserify = require("browserify"),
    watchify = require("watchify-cache"),
    streamp = require("streamp"),
    ul = require("ul"),
    os = require("os"),
    abs = require("abs"),
    isRemote = require("url-remote"),
    babelify = require("babelify"),
    presetEnv = require("@babel/preset-env"),
    reactify = require("babel-preset-react"),
    noStrictMode = require("babel-plugin-transform-remove-strict-mode"),
    transformRuntime = require("@babel/plugin-transform-runtime"),
    uglifyify = require("uglifyify"),
    CleanCSS = require("clean-css"),
    postcss = require("postcss"),
    watch = require("fwatcher"),
    logger = require("cute-logger"),
    parseUrl = require("parse-url"),
    atImport = require("postcss-import"),
    postcssUrl = require("postcss-url"),
    postcssClean = require("postcss-clean"),
    idy = require("idy"),
    noop = require("noop6"),
    matchAll = require("match-all"),
    forEach = require("iterate-object"),
    escapeRegex = require("regex-escape"),
    through = require("through2"),
    collapse = require("bundle-collapser/plugin"),
    cssPreset = require("postcss-preset-env"),
    cssnextVariables = require("postcss-css-variables"),
    path = require("path"),
    RucksackLite = require("rucksack-lite");

module.exports = function (_RucksackLite) {
    _inherits(Rucksack, _RucksackLite);

    /**
     * Ruckasck
     * Creates a new instance of `Ruckasck`.
     *
     * @param  {Object} opts The Rucksack options.
     * @return {Object}      The Rucksack instance.
     */
    function Rucksack(opts) {
        var _browserify;

        _classCallCheck(this, Rucksack);

        var _this = _possibleConstructorReturn(this, (Rucksack.__proto__ || Object.getPrototypeOf(Rucksack)).call(this, opts));

        opts = _this.opts = ul.merge(opts, {
            jsOutput: process.stdout,
            cssOutput: process.stdout,
            jsUrl: "",
            cssUrl: "",
            development: false,
            browserifyCache: {},
            browserifyPackageCache: {},
            plugins: [],
            cacheFile: ".rucksack-cache.json",
            strictMode: false,
            cssUrlHook: noop,
            aliases: {}
        });

        _this._watchingCssFiles = {};
        _this.cssBlacklist = [];

        if (!opts.development) {
            opts.plugins.push(collapse);
        }

        _this.browserify = browserify((_browserify = {
            debug: opts.development,
            packageCache: opts.browserifyPackageCache,
            plugin: opts.plugins,
            cache: opts.cacheFile ? watchify.getCache(opts.cacheFile) : {}
        }, _defineProperty(_browserify, "packageCache", {}), _defineProperty(_browserify, "fullPaths", false), _browserify));

        opts.cacheFile = opts.cacheFile || os.tmpdir() + "/" + idy();
        if (opts.cacheFile) {
            _this.browserify = watchify(_this.browserify, {
                watch: opts.development,
                cacheFile: opts.cacheFile
            });
        }

        if (opts.development) {
            _this.browserify.on("update", function () {
                _this.bundleJS();
            });
        }

        if (opts.development) {
            opts.babelify = false;
            opts.uglify = false;
        }

        var babelPlugins = [];
        babelPlugins.push(transformRuntime.default);
        if (_this.opts.strictMode === false) {
            babelPlugins.push([noStrictMode]);
        }

        _this.browserify.transform(babelify, {
            global: true,
            babelrc: false,
            presets: [reactify, presetEnv],
            plugins: babelPlugins
        });

        var replacements = [];
        forEach(_this.opts.aliases, function (target, source) {
            target = path.normalize(target);
            if (path.sep === "\\") {
                target = target.replace(/\\/g, "\\\\");
            }
            // import ... from "bloggify"
            replacements.push([new RegExp(" from (\"|')" + escapeRegex(source) + "(\"|')", "g"), " from '" + target + "'"]);
            // require("bloggify")
            replacements.push([new RegExp("require\\((\"|')" + escapeRegex(source) + "(\"|')\\)", "g"), "require('" + target + "')"]);
        });

        // Aliases
        _this.browserify.transform({ global: true }, function (file) {
            return through(function (buf, enc, next) {
                buf = buf.toString("utf8");
                replacements.forEach(function (_ref) {
                    var _ref2 = _slicedToArray(_ref, 2),
                        source = _ref2[0],
                        target = _ref2[1];

                    buf = buf.replace(source, target);
                });
                this.push(buf);
                next();
            });
        });

        if (opts.uglify !== false) {
            _this.browserify = _this.browserify.transform({
                global: true
            }, uglifyify);
        }

        _this.remote = {
            js: [],
            css: []
        };
        return _this;
    }

    /**
     * _watchCSS
     * Watch the CSS paths.
     *
     * @name _watchCSS
     * @function
     * @param  {String} resPath The CSS resource path.
     */


    _createClass(Rucksack, [{
        key: "_watchCSS",
        value: function _watchCSS(resPath) {
            var _this2 = this;

            if (Array.isArray(resPath)) {
                return resPath.forEach(function (c) {
                    return _this2._watchCSS(c);
                });
            }
            resPath = abs(resPath);
            if (this._watchingCssFiles[resPath]) {
                return;
            }
            this._watchingCssFiles[resPath] = watch(resPath, function (err, ev) {
                setTimeout(function () {
                    logger.log("CSS File Updated: " + resPath);
                    _this2.bundleCSS();
                }, 60);
            });
        }

        /**
         * addCSS
         * Adds a new CSS path.
         *
         * @name addCSS
         * @function
         * @param {String} resPath The CSS resource path to add.
         * @param {Boolean} inline Whether to add the CSS content inline or not.
         */

    }, {
        key: "addCSS",
        value: function addCSS(resPath, inline) {
            _get(Rucksack.prototype.__proto__ || Object.getPrototypeOf(Rucksack.prototype), "addCSS", this).call(this, resPath, inline);
            this._watchCSS(resPath);
        }

        /**
         * bundleJS
         * Bundles the JS files.
         *
         * @param  {String} output   The output of the JS script.
         * @param  {Function} cb     The callback function.
         */

    }, {
        key: "bundleJS",
        value: function bundleJS(output, cb) {
            var _this3 = this;

            var maybeOutputFileName = output = output || this.opts.jsOutput;
            if (typeof maybeOutputFileName === "string") {
                maybeOutputFileName = path.basename(maybeOutputFileName);
            } else {
                maybeOutputFileName = "";
            }

            var bundling = this.browserify.bundle({
                debug: this.opts.development
            });

            if (!bundling) {
                return cb && cb();
            }
            if (typeof output === "string") {
                output = new streamp.writable({ path: output, flags: "w" });
            }
            logger.log("Bundling " + (maybeOutputFileName ? maybeOutputFileName : " the scripts."));
            bundling.on("error", function (e) {
                if (!cb) {
                    if (e.codeFrame) {
                        logger.log(e.message + "\n" + e.codeFrame, "error");
                    } else {
                        logger.log(e, "error");
                        console.error(e.stack);
                    }
                }
                cb && cb(e);
            });
            bundling.pipe(output);
            bundling.on("end", function () {
                if (maybeOutputFileName) {
                    logger.log("Bundled: " + maybeOutputFileName);
                }
                _this3.browserify.write();
                cb && cb();
            });
        }

        /**
         * bundleCSS
         * Bundles the CSS files.
         *
         * @param  {String} output   The output of the CSS script.
         * @param  {Function} cb     The callback function.
         * @return {String}          The URL of the script.
         */

    }, {
        key: "bundleCSS",
        value: function bundleCSS(output, cb) {
            var _this4 = this;

            var maybeOutputFileName = output = output || this.opts.cssOutput;
            if (typeof output === "string") {
                output = new streamp.writable({ path: output, flags: "w" });
            }

            if (typeof maybeOutputFileName === "string") {
                maybeOutputFileName = path.basename(maybeOutputFileName);
            } else {
                maybeOutputFileName = "";
            }

            var cssImports = this.cssPaths.map(function (c) {
                return "@import url('" + c + "');";
            }).join("\n");

            var cssBundler = postcss();

            var extensions = [atImport({
                root: "/",
                blacklist: this.cssBlacklist,
                onImport: function onImport(paths) {
                    _this4._watchCSS(paths);
                }
            }), [postcssUrl, {
                url: function url(_url, decl, from, dirname, to, options, result) {
                    var newUrl = _this4.opts.cssUrlHook(_url, decl, from, dirname, to, options, result);
                    if (newUrl) {
                        return newUrl;
                    }
                    return _url;
                }
            }], cssPreset({ stage: 0 }), cssnextVariables({
                features: {
                    customProperties: false
                }
            })];

            if (!this.opts.development) {
                extensions.push([postcssClean, { level: 2 }]);
            }

            extensions.forEach(function (c) {
                cssBundler = Array.isArray(c) ? cssBundler.use(c[0](c[1])) : cssBundler = cssBundler.use(c);
            });

            logger.log("Bundling " + (maybeOutputFileName ? maybeOutputFileName : " the styles."));
            return cssBundler.process(cssImports).then(function (result) {
                var messages = result.messages.map(function (c) {
                    return {
                        message: c.text,
                        type: c.type === "warning" ? "warn" : c.type
                    };
                });
                messages.forEach(function (c) {
                    if (c.message) {
                        logger.log(c.message, c.type);
                    }
                });
                output.write(result.css);
                output.on("close", function () {
                    cb && cb();
                });
                if (output !== process.stdout) {
                    if (maybeOutputFileName) {
                        logger.log("Bundled: " + maybeOutputFileName);
                    }
                    output.end();
                }
            }).catch(function (e) {
                logger.log(e, "error");
                cb && cb(e);
            });
        }
    }]);

    return Rucksack;
}(RucksackLite);

==> rucksack-6.1.0.tgz: package/lib/index.js <==
"use strict";

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _get = function get(object, property, receiver) { if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { return get(parent, property, receiver); } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } };

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var browserify = require("browserify"),
    watchify = require("watchify-cache"),
    streamp = require("streamp"),
    ul = require("ul"),
    os = require("os"),
    abs = require("abs"),
    isRemote = require("url-remote"),
    babelify = require("babelify"),
    presetEnv = require("@babel/preset-env"),
    reactify = require("babel-preset-react"),
    noStrictMode = require("babel-plugin-transform-remove-strict-mode"),
    transformRuntime = require("@babel/plugin-transform-runtime"),
    uglifyify = require("uglifyify"),
    CleanCSS = require("clean-css"),
    postcss = require("postcss"),
    watch = require("fwatcher"),
    logger = require("cute-logger"),
    atImport = require("postcss-import"),
    postcssUrl = require("postcss-url"),
    cssNano = require("cssnano"),
    idy = require("idy"),
    noop = require("noop6"),
    matchAll = require("match-all"),
    forEach = require("iterate-object"),
    escapeRegex = require("regex-escape"),
    through = require("through2"),
    collapse = require("bundle-collapser/plugin"),
    cssPreset = require("postcss-preset-env"),
    cssnextVariables = require("postcss-css-variables"),
    path = require("path"),
    RucksackLite = require("rucksack-lite");

module.exports = function (_RucksackLite) {
    _inherits(Rucksack, _RucksackLite);

    /**
     * Ruckasck
     * Creates a new instance of `Ruckasck`.
     *
     * @param  {Object} opts The Rucksack options.
     * @return {Object}      The Rucksack instance.
     */
    function Rucksack(opts) {
        var _browserify;

        _classCallCheck(this, Rucksack);

        var _this = _possibleConstructorReturn(this, (Rucksack.__proto__ || Object.getPrototypeOf(Rucksack)).call(this, opts));

        opts = _this.opts = ul.merge(opts, {
            jsOutput: process.stdout,
            cssOutput: process.stdout,
            jsUrl: "",
            cssUrl: "",
            development: false,
            browserifyCache: {},
            browserifyPackageCache: {},
            plugins: [],
            cacheFile: ".rucksack-cache.json",
            strictMode: false,
            cssUrlHook: noop,
            aliases: {}
        });

        opts.cssExtensions = ul.merge(opts.cssExtensions, {
            atImport: true,
            postcssUrl: true,
            cssPreset: true,
            cssnextVariables: true
        });

        _this._watchingCssFiles = {};
        _this.cssBlacklist = [];

        if (!opts.development) {
            opts.plugins.push(collapse);
        }

        _this.browserify = browserify((_browserify = {
            debug: opts.development,
            packageCache: opts.browserifyPackageCache,
            plugin: opts.plugins,
            cache: opts.cacheFile ? watchify.getCache(opts.cacheFile) : {}
        }, _defineProperty(_browserify, "packageCache", {}), _defineProperty(_browserify, "fullPaths", false), _browserify));

        opts.cacheFile = opts.cacheFile || os.tmpdir() + "/" + idy();
        if (opts.cacheFile) {
            _this.browserify = watchify(_this.browserify, {
                watch: opts.development,
                cacheFile: opts.cacheFile
            });
        }

        if (opts.development) {
            _this.browserify.on("update", function () {
                _this.bundleJS();
            });
        }

        if (opts.development) {
            opts.babelify = false;
            opts.uglify = false;
        }

        var babelPlugins = [];
        babelPlugins.push(transformRuntime.default);
        if (_this.opts.strictMode === false) {
            babelPlugins.push([noStrictMode]);
        }

        _this.browserify.transform(babelify, {
            global: true,
            babelrc: false,
            presets: [reactify, presetEnv],
            plugins: babelPlugins
        });

        var replacements = [];
        forEach(_this.opts.aliases, function (target, source) {
            target = path.normalize(target);
            if (path.sep === "\\") {
                target = target.replace(/\\/g, "\\\\");
            }
            // import ... from "bloggify"
            replacements.push([new RegExp(" from (\"|')" + escapeRegex(source) + "(\"|')", "g"), " from '" + target + "'"]);
            // require("bloggify")
            replacements.push([new RegExp("require\\((\"|')" + escapeRegex(source) + "(\"|')\\)", "g"), "require('" + target + "')"]);
        });

        // Aliases
        _this.browserify.transform({ global: true }, function (file) {
            return through(function (buf, enc, next) {
                buf = buf.toString("utf8");
                replacements.forEach(function (_ref) {
                    var _ref2 = _slicedToArray(_ref, 2),
                        source = _ref2[0],
                        target = _ref2[1];

                    buf = buf.replace(source, target);
                });
                this.push(buf);
                next();
            });
        });

        if (opts.uglify !== false) {
            _this.browserify = _this.browserify.transform({
                global: true
            }, uglifyify);
        }

        _this.remote = {
            js: [],
            css: []
        };
        return _this;
    }

    /**
     * _watchCSS
     * Watch the CSS paths.
     *
     * @name _watchCSS
     * @function
     * @param  {String} resPath The CSS resource path.
     */


    _createClass(Rucksack, [{
        key: "_watchCSS",
        value: function _watchCSS(resPath) {
            var _this2 = this;

            if (Array.isArray(resPath)) {
                return resPath.forEach(function (c) {
                    return _this2._watchCSS(c);
                });
            }
            resPath = abs(resPath);
            if (this._watchingCssFiles[resPath]) {
                return;
            }
            this._watchingCssFiles[resPath] = watch(resPath, function (err, ev) {
                setTimeout(function () {
                    logger.log("CSS File Updated: " + resPath);
                    _this2.bundleCSS();
                }, 60);
            });
        }

        /**
         * addCSS
         * Adds a new CSS path.
         *
         * @name addCSS
         * @function
         * @param {String} resPath The CSS resource path to add.
         * @param {Boolean} inline Whether to add the CSS content inline or not.
         */

    }, {
        key: "addCSS",
        value: function addCSS(resPath, inline) {
            _get(Rucksack.prototype.__proto__ || Object.getPrototypeOf(Rucksack.prototype), "addCSS", this).call(this, resPath, inline);
            this._watchCSS(resPath);
        }

        /**
         * bundleJS
         * Bundles the JS files.
         *
         * @param  {String} output   The output of the JS script.
         * @param  {Function} cb     The callback function.
         */

    }, {
        key: "bundleJS",
        value: function bundleJS(output, cb) {
            var _this3 = this;

            var maybeOutputFileName = output = output || this.opts.jsOutput;
            if (typeof maybeOutputFileName === "string") {
                maybeOutputFileName = path.basename(maybeOutputFileName);
            } else {
                maybeOutputFileName = "";
            }

            var bundling = this.browserify.bundle({
                debug: this.opts.development
            });

            if (!bundling) {
                return cb && cb();
            }
            if (typeof output === "string") {
                output = new streamp.writable({ path: output, flags: "w" });
            }
            logger.log("Bundling " + (maybeOutputFileName ? maybeOutputFileName : " the scripts."));
            bundling.on("error", function (e) {
                if (!cb) {
                    if (e.codeFrame) {
                        logger.log(e.message + "\n" + e.codeFrame, "error");
                    } else {
                        logger.log(e, "error");
                        console.error(e.stack);
                    }
                }
                cb && cb(e);
            });
            bundling.pipe(output);
            bundling.on("end", function () {
                if (maybeOutputFileName) {
                    logger.log("Bundled: " + maybeOutputFileName);
                }
                _this3.browserify.write();
                cb && cb();
            });
        }

        /**
         * bundleCSS
         * Bundles the CSS files.
         *
         * @param  {String} output   The output of the CSS script.
         * @param  {Function} cb     The callback function.
         * @return {String}          The URL of the script.
         */

    }, {
        key: "bundleCSS",
        value: function bundleCSS(output, cb) {
            var _this4 = this;

            var maybeOutputFileName = output = output || this.opts.cssOutput;
            if (typeof output === "string") {
                output = new streamp.writable({ path: output, flags: "w" });
            }

            if (typeof maybeOutputFileName === "string") {
                maybeOutputFileName = path.basename(maybeOutputFileName);
            } else {
                maybeOutputFileName = "";
            }

            var cssImports = this.cssPaths.map(function (c) {
                return "@import url('" + c + "');";
            }).join("\n");

            var cssBundler = postcss();

            var extensions = [this.opts.cssExtensions.atImport && atImport({
                root: "/",
                blacklist: this.cssBlacklist,
                onImport: function onImport(paths) {
                    _this4._watchCSS(paths);
                }
            }), this.opts.cssExtensions.postcssUrl && [postcssUrl, {
                url: function url(_url, decl, from, dirname, to, options, result) {
                    var newUrl = _this4.opts.cssUrlHook(_url, decl, from, dirname, to, options, result);
                    if (newUrl) {
                        return newUrl;
                    }
                    return _url;
                }
            }], this.opts.cssExtensions.cssPreset && cssPreset({ stage: 0 }), this.opts.cssExtensions.cssnextVariables && cssnextVariables({
                features: {
                    customProperties: false
                }
            })].filter(Boolean);

            if (!this.opts.development) {
                extensions.push([cssNano, { preset: "default" }]);
            }

            extensions.forEach(function (c) {
                cssBundler = Array.isArray(c) ? cssBundler.use(c[0](c[1])) : cssBundler = cssBundler.use(c);
            });

            logger.log("Bundling " + (maybeOutputFileName ? maybeOutputFileName : " the styles."));
            return cssBundler.process(cssImports).then(function (result) {
                var messages = result.messages.map(function (c) {
                    return {
                        message: c.text,
                        type: c.type === "warning" ? "warn" : c.type
                    };
                });
                messages.forEach(function (c) {
                    if (c.message) {
                        logger.log(c.message, c.type);
                    }
                });
                output.write(result.css);
                output.on("close", function () {
                    cb && cb();
                });
                if (output !== process.stdout) {
                    if (maybeOutputFileName) {
                        logger.log("Bundled: " + maybeOutputFileName);
                    }
                    output.end();
                }
            }).catch(function (e) {
                logger.log(e, "error");
                cb && cb(e);
            });
        }
    }]);

    return Rucksack;
}(RucksackLite);
